@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -30,13 +30,13 @@ from stalker.models.mixins import ProjectMixin
 # create a new mixed in SimpleEntity
 from stalker.models.entity import SimpleEntity
 
+
 class DeclProjMixA(SimpleEntity, ProjectMixin):
     __tablename__ = "DeclProjMixAs"
     __mapper_args__ = {"polymorphic_identity": "DeclProjMixA"}
     a_id = Column("id", Integer, ForeignKey("SimpleEntities.id"),
                   primary_key=True)
 
-
     def __init__(self, **kwargs):
         super(DeclProjMixA, self).__init__(**kwargs)
         ProjectMixin.__init__(self, **kwargs)
@@ -48,7 +48,6 @@ class DeclProjMixB(SimpleEntity, ProjectMixin):
     b_id = Column("id", Integer, ForeignKey("SimpleEntities.id"),
                   primary_key=True)
 
-
     def __init__(self, **kwargs):
         super(DeclProjMixB, self).__init__(**kwargs)
         ProjectMixin.__init__(self, **kwargs)
@@ -58,28 +57,26 @@ class ProjectMixinTester(unittest2.TestCase):
     """tests ProjectMixin
     """
 
-
     def setUp(self):
         """setup the test
         """
-
         self.test_stat1 = Status(name="On Hold", code="OH")
         self.test_stat2 = Status(name="Work In Progress", code="WIP")
         self.test_stat3 = Status(name="Approved", code="APP")
 
-        self.test_a_statusList = StatusList(
+        self.test_status_list_1 = StatusList(
             name="A Statuses",
             statuses=[self.test_stat1, self.test_stat3],
             target_entity_type=DeclProjMixA,
-            )
+        )
 
-        self.test_b_statusList = StatusList(
+        self.test_status_list_2 = StatusList(
             name="B Statuses",
             statuses=[self.test_stat2, self.test_stat3],
             target_entity_type=DeclProjMixB
         )
 
-        self.test_project_statusList = StatusList(
+        self.test_project_statuses = StatusList(
             name="Project Statuses",
             statuses=[self.test_stat2, self.test_stat3],
             target_entity_type=Project
@@ -99,23 +96,22 @@ class ProjectMixinTester(unittest2.TestCase):
             name="Test Project",
             code='tp',
             type=self.test_project_type,
-            status_list=self.test_project_statusList,
+            status_list=self.test_project_statuses,
             repository=self.test_repository,
         )
 
         self.kwargs = {
             "name": "ozgur",
-            "status_list": self.test_a_statusList,
+            "status_list": self.test_status_list_1,
             "project": self.test_project,
-            }
+        }
 
         self.test_a_obj = DeclProjMixA(**self.kwargs)
 
     def tearDown(self):
         """clean up the test
         """
-        if DBSession:
-            DBSession.remove()
+        DBSession.remove()
 
     def test_project_attribute_is_working_properly(self):
         """testing if the project attribute is working properly
